@@ -91,7 +91,7 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
                     .iter()
                     .filter_map(|sect| section_content!(sect, "SolutionConfigurationPlatforms"))
                     .flatten()
-                    .filter_map(|expr| Conf::from_expr(expr));
+                    .filter_map(Conf::from_expr);
 
                 sol.solution_configs.extend(configs_and_platforms);
 
@@ -99,7 +99,7 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
                     .iter()
                     .filter_map(|sect| section_content!(sect, "ProjectConfigurationPlatforms"))
                     .flatten()
-                    .filter_map(|expr| ProjectConfigs::from_section_content_key(expr))
+                    .filter_map(ProjectConfigs::from_section_content_key)
                     .group_by(|x| x.project_id)
                     .into_iter()
                     .map(|(pid, project_configs)| {
@@ -112,7 +112,7 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
                     .iter()
                     .filter_map(|sect| section_content!(sect, "ProjectConfiguration"))
                     .flatten()
-                    .filter_map(|expr| ProjectConfigs::from_section_content(expr))
+                    .filter_map(ProjectConfigs::from_section_content)
                     .group_by(|x| x.project_id)
                     .into_iter()
                     .map(|(pid, project_configs)| {
@@ -141,7 +141,10 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
                 sol.project_configs.extend(project_configs_platforms);
                 sol.project_configs.extend(project_configs);
             }
-            Expr::Comment(s) => sol.product = s,
+            Expr::Comment(s) => {
+                let skip: &[_] = &['#', ' '];
+                sol.product = s.trim_start_matches(skip)
+            }
             _ => {}
         }
     }
@@ -168,8 +171,10 @@ mod tests {
         // Assert
         assert_that(&result).is_some();
         let solution = result.unwrap();
-        assert_that(&solution.projects.len()).is_equal_to(solution.dependencies.node_count());
-        assert_that(&solution.dependencies.edge_count()).is_equal_to(4);
+        assert_that!(solution.projects.len()).is_equal_to(solution.dependencies.node_count());
+        assert_that!(solution.dependencies.edge_count()).is_equal_to(4);
+        assert_that!(solution.format).is_equal_to("12.00");
+        assert_that!(solution.product).is_equal_to("Visual Studio 15");
         println!(
             "{:?}",
             Dot::with_config(&solution.dependencies, &[Config::EdgeNoLabel])
